.. _contributing:

Contributing to semver
======================

The semver source code is managed using Git and is hosted on GitHub::

   git clone git://github.com/python-semver/python-semver


.. include:: prerequisites.rst
   :start-after: -text-begin-


.. toctree::
    :maxdepth: 1
    :caption: More topics
    :includehidden:

    report-bugs
    run-test-suite
    doc-semver
    add-changelog-entry
    release-procedure
    finish-release


.. _pull request: https://github.com/python-semver/python-semver/pulls
